@@ -8,7 +8,6 @@ import requests
 from argparse import ArgumentParser
 import glob
 from almdrlib.client import _YamlOrderedLoader
-
 OPENAPI_SCHEMA_URL = 'https://raw.githubusercontent.com/OAI/OpenAPI-Specification/master/schemas/v3.0/schema.json'
 
 
@@ -26,6 +25,11 @@ def validate_definition(definition_file):
         except ValidationError as e:
             print(f"Validation has failed - schema validation has failed {e}")
             exit(1)
+        except TypeError:
+            print(f"Validation has failed - json schema trips over integer keys, please "
+                  f"validate your response codes are not integers, check also other keys are not integers"
+                  f"if any of it are, quote it, '200', '400' etc")
+            exit(1)
         print("Validation passed")
     else:
         print("Input is empty")
@@ -39,7 +43,7 @@ if __name__ == "__main__":
     options = parser.parse_args()
     r = requests.get(OPENAPI_SCHEMA_URL)
     schema = r.json()
-    files = glob.glob(f"{options.dir}/*.yaml")
+    files = glob.glob(f"{options.dir}/*.v[1-9]*.yaml")
     if files:
         for file in files:
             validate_definition(file)
