@@ -9,6 +9,8 @@ elif command -v python3.7; then
   PYTHON=python3.7
 elif command -v python3.6; then
   PYTHON=python3.6
+elif command -v python3; then
+  PYTHON=python3
 else
   echo "No suitable python3 interpreter is found"
   exit 1
@@ -24,4 +26,4 @@ if $PYTHON -m venv $TEMP; then
   else
     $PYTHON $TEMP/validate_my_definition.py -d $1 && rm -rf $TEMP
   fi
-fi
\ No newline at end of file
+fi
